// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { useEffect, useState } from 'react';
import {
  assignNewGraphQueryResult,
  useAppDispatch,
} from '@graphpolaris/shared/data-access/store';
import { AuthorizationHandler } from '@graphpolaris/shared/data-access/authorization';
import GridLayout from 'react-grid-layout';
import Panel from '../components/panels/panel';
import { RawJSONVis } from '../components/visualisations/rawjsonvis/rawjsonvis';
import SemanticSubstrates from '../components/visualisations/semanticsubstrates/semanticsubstrates';
import LoginScreen from '../components/login/loginScreen';
import { OurThemeProvider } from '@graphpolaris/shared/data-access/theme';
import Schema from '../components/schema/schema';

function useIsAuthorized() {
  const [userAuthorized, setUserAuthorized] = useState(false);

  const authCallback = () => {
    setUserAuthorized(true);
  };

  AuthorizationHandler.instance().setCallback(authCallback);

  // Attempt to Authorize the user
  const authorize = async () => {
    const authorized = await AuthorizationHandler.instance().Authorize();
    setUserAuthorized(authorized);
  };

  useEffect(() => {
    authorize();
  }, []);

  return userAuthorized;
}

export function App() {
  const dispatch = useAppDispatch();
  const userIsAuthorized = useIsAuthorized();

  return (
    <OurThemeProvider>
      {!userIsAuthorized && <LoginScreen />}
      <GridLayout
        className="layout"
        cols={10}
        rowHeight={30}
        width={window.innerWidth}
      >
        <div
          key="schema-panel"
          data-grid={{ x: 0, y: 0, w: 3, h: 30, maxW: 5, isDraggable: false }}
        >
          <Panel content="Schema Panel" color="red">
            <Schema />
          </Panel>
        </div>
        <div
          key="query-panel"
          data-grid={{ x: 3, y: 20, w: 5, h: 10, maxH: 20, isDraggable: false }}
        >
          <Panel content="Query Panel" color="blue"></Panel>
        </div>
        <div
          key="visualisation-panel"
          data-grid={{ x: 3, y: 0, w: 7, h: 20, isDraggable: false }}
        >
          <Panel content="Visualisation Panel" color="green">
            <div>
              <button
                onClick={() =>
                  dispatch(
                    assignNewGraphQueryResult({
                      nodes: [
                        {
                          id: 'agent/007',
                          attributes: { name: 'Daniel Craig' },
                        },
                      ],
                      links: [],
                    })
                  )
                }
              >
                Load in mock result
              </button>
              <button
                onClick={() =>
                  dispatch(assignNewGraphQueryResult({ nodes: [], links: [] }))
                }
              >
                Remove mock result
              </button>
            </div>
            <RawJSONVis />
            <SemanticSubstrates />
            <div />
          </Panel>
        </div>
        <div
          key="history-panel"
          data-grid={{ x: 8, y: 20, w: 2, h: 10, isDraggable: false }}
        >
          <Panel content="History Channel" color="purple"></Panel>
        </div>
      </GridLayout>
    </OurThemeProvider>
  );
}

export default App;
