import { parseSchemaFromBackend } from '@graphpolaris/schema/schema-usecases';
import {
  SchemaFromBackend,
  schemaSlice,
  setSchema,
  store,
} from '@graphpolaris/shared/data-access/store';
import {
  movieSchema,
  northWindSchema,
  twitterSchema,
} from '@graphpolaris/shared/mock-data';
import { configureStore } from '@reduxjs/toolkit';
import { ComponentMeta, ComponentStory } from '@storybook/react';
import React from 'react';
import { Provider } from 'react-redux';
import Schema from './schema';

export default {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Schema',
  component: Schema,
  decorators: [
    (story) => (
      <div style={{ padding: '3rem' }}>
        <Provider store={Mockstore}>{story()}</Provider>
      </div>
    ),
  ],
} as ComponentMeta<typeof Schema>;

const Template: ComponentStory<typeof Schema> = (args) => <Schema {...args} />;

// // A super-simple mock of a redux store
const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
  },
});

export const TestWithSchema = Template.bind({});

TestWithSchema.play = async () => {
  const parsed = parseSchemaFromBackend(twitterSchema as SchemaFromBackend);
  Mockstore.dispatch(setSchema(parsed.export()));
};
